The AEA framework has two commercial roles which are outlined below.


## Open source technology for everyone

We are creating infrastructure for developers to build their own agent-based solutions. 

AEA users are, among others:

* Data scientists.
* Economists.
* Researchers (Artificial Intelligence, Machine Learning, Multi-Agent Systems).
* Engineers.
* Machine learning experts.
* Independent developers.
* Students and academics.
* Crypto connoisseurs and enthusiasts.
* Web developers.


## Decentralised agent economy for businesses

We envisage the AEA framework to be used by businesses of all sizes to deploy multi-agent solutions into the decentralized agent economy cultivated by Fetch.ai.

With start up grants we will kick start solutions while testing product-market fit and identifying our user base.



<br />

